@@ -5,8 +5,10 @@ from django.template import RequestContext
 from django.contrib.auth.decorators import login_required
 from django.http import HttpResponseRedirect
 from django.utils.translation import ugettext_lazy as _
+from django.core.urlresolvers import reverse_lazy
 from django.shortcuts import redirect
 from django.contrib.sites.models import Site
+from django.contrib import messages
 import models as mymodels
 import forms as myforms
 
@@ -22,10 +24,31 @@ class Photos(ListView):
     paginate_by = 51
 
     def get_queryset(self):
-        return mymodels.Photo.objects.all().filter(status=1).order_by('-capture_date')
+        return mymodels.Photo.objects.all().filter(status=1, folder__isnull=True).order_by('-capture_date')
 
     def get_context_data(self, **kwargs):
         context = super(Photos, self).get_context_data(**kwargs)
+        folders = mymodels.Folder.objects.filter(status=1)
+
+        context.update({
+            'title': _(u'Photos'),
+            'folders': folders,
+        })
+        return context
+
+
+class PhotosFolder(ListView):
+
+    template_name = "rgallery/photos.html"
+    context_object_name = "photos"
+
+    def get_queryset(self):
+        folder = mymodels.Folder.objects.get(slug=self.kwargs['folder'])
+        return mymodels.Photo.objects.all().filter(status=1, folder=folder).order_by('-capture_date')
+
+    def get_context_data(self, **kwargs):
+        context = super(PhotosFolder, self).get_context_data(**kwargs)
+
         context.update({
             'title': _(u'Photos'),
         })
@@ -39,7 +62,7 @@ class Videos(ListView):
     paginate_by = 6
 
     def get_queryset(self):
-        vid = mymodels.Video.objects.all().filter(status=1).order_by('-capture_date')
+        vid = mymodels.Video.objects.all().filter(status=1, folder__isnull=True).order_by('-capture_date')
         print vid
         return vid
 
